@@ -66,6 +66,7 @@ enum _ERROR_PACKET_NUMBERS {
 typedef enum {
 	STBIN_ST = 0x01,
 	STBIN_ER = 0x02,
+	STBIN_WR = 0x04,	/* 2004.03.25 add for setting warning */ 
 	STBIN_IC = 0x0f
 } StField;
 
@@ -374,7 +375,7 @@ post_prt_status (P_CBTD_INFO p_info)
 			return 1;
 		}
 
-		/* $B%9%F!<%?%9>pJsJQ49(B */
+		/* ơѴ */
 		if (rbuf[7] == '2') {
 			p_info->prt_status_len = change_status_format(rbuf, rsize,
 								      p_info->prt_status,
@@ -428,23 +429,27 @@ post_prt_status (P_CBTD_INFO p_info)
 		/* set a clock */
 		if (_comserv_first_flag)
 		{
-			time_t tp;
-			struct tm *ltime;
+			if( point[4] == '4' || point[4] == '0' ){
+				/* statusʤȤꤹ褦˽      */
+				/* statusERRORǤǽ                       */
+				/* for PM-980C				       */
+				time_t tp;
+				struct tm *ltime;
 	
-			tp = time(&tp);
-			ltime = localtime(&tp);
-			timer_set_command[5] = (1900 + ltime->tm_year) >> 8;
-			timer_set_command[6] = (1900 + ltime->tm_year) & 0xff;
-			timer_set_command[7] = ltime->tm_mon + 1;
-			timer_set_command[8] = ltime->tm_mday;
-			timer_set_command[9] = ltime->tm_hour;
-			timer_set_command[10] = ltime->tm_min;
-			timer_set_command[11] = ltime->tm_sec;
-			csize = sizeof (timer_set_command);
-			rsize = PRT_STATUS_MAX;
-			write_prt_command (p_info, timer_set_command, csize, rbuf, &rsize);
-
-			_comserv_first_flag = 0;
+				tp = time(&tp);
+				ltime = localtime(&tp);
+				timer_set_command[5] = (1900 + ltime->tm_year) >> 8;
+				timer_set_command[6] = (1900 + ltime->tm_year) & 0xff;
+				timer_set_command[7] = ltime->tm_mon + 1;
+				timer_set_command[8] = ltime->tm_mday;
+				timer_set_command[9] = ltime->tm_hour;
+				timer_set_command[10] = ltime->tm_min;
+				timer_set_command[11] = ltime->tm_sec;
+				csize = sizeof (timer_set_command);
+				rsize = PRT_STATUS_MAX;
+				write_prt_command (p_info, timer_set_command, csize, rbuf, &rsize);
+				_comserv_first_flag = 0;
+			}
 		}
 	}
 
@@ -729,7 +734,7 @@ change_status_format(unsigned char *bdata, size_t bsize,
 	unsigned char *point;
 	size_t count = 0;
 
-	/* $B%X%C%@%A%'%C%/(B */
+	/* إåå */
 	if (!bdata || memcmp(bdata, bheader, sizeof(bheader))) {
 		return 0;
 	}
@@ -741,18 +746,20 @@ change_status_format(unsigned char *bdata, size_t bsize,
 	/* Status Codes */
 	point = scan_bin_status(STBIN_ST, bdata, bsize);
 	if (point && count + 6 < csize) {
-		sprintf(cdata + count, "ST:%02x;", (int)point[2]);
+		/* 2004.03.02 update "%2x" -> "%2X" */
+		sprintf(cdata + count, "ST:%02X;", (int)point[2]);
 		count += 6;
 	}
 	
 	/* Error Codes */
 	point = scan_bin_status(STBIN_ER, bdata, bsize);
 	if (point && count + 6 < csize) {
-		sprintf(cdata + count, "ER:%02x;", (int)point[2]);
+		/* 2004.03.02 update "%2x" -> "%2X" */
+		sprintf(cdata + count, "ER:%02X;", (int)point[2]);
 		count += 6;
 	}
 
-	/* Cuantity of ink */
+	/* Quantity of ink */
 	point = scan_bin_status(STBIN_IC, bdata, bsize);
 	if (point) {
 		int i, n;
@@ -765,7 +772,8 @@ change_status_format(unsigned char *bdata, size_t bsize,
 			point += 3;
 
 			for (i = 0; i < n; i++) {
-				sprintf(cdata + count, "%02x", (int)point[i * 3 + 2]);
+				/* 2004.03.02 update "%2x" -> "%2X" */
+				sprintf(cdata + count, "%02X", (int)point[i * 3 + 2]);
 				count += 2;
 			}
 			sprintf(cdata + count, ";");
@@ -774,10 +782,20 @@ change_status_format(unsigned char *bdata, size_t bsize,
 	}
 
 	/* Warning Codes */
-/* 	point = scan_bin_status(STBIN_WR, bdata, bsize); */
-/* 	if (point && count ) { */
-/* 		int i, n; */
-/* 	} */
+ 	point = scan_bin_status(STBIN_WR, bdata, bsize); 
+ 	if (point ) {
+ 		int i, n; 
+		n = point[1]; 	/* no. of warning */
+		for ( i = 0; i < n ; i++ ){
+			/* check only ink low */
+			if( point[i + 2 ] >= 0x10 && point[i+2] <= 0x19 ){
+				sprintf(cdata + count, "WR:%02X;", (int)point[i+2]);
+				count += 6;
+				/* not set all warning, so break */
+				break;
+			}
+		}
+ 	}
 
 	point = scan_bin_status(STBIN_IC, bdata, bsize);
 	if (point) {
@@ -797,7 +815,15 @@ change_status_format(unsigned char *bdata, size_t bsize,
 
 				switch (point[i * 3 + 1]) {
 				case 0x00:
-					strncpy(key, "1101", 4);
+					if( i == 3 ){
+						/* PX-G900 Matte Black */
+						strncpy(key, "B140", 4);
+					}else if( i == 4 ){
+						/* PX-G900 Photo Black */
+						strncpy(key, "A140", 4);
+					}else{
+						strncpy(key, "1101", 4);
+					}
 					break;
 				case 0x01:
 					strncpy(key, "3202", 4);
@@ -820,6 +846,23 @@ change_status_format(unsigned char *bdata, size_t bsize,
 				case 0x07:
 					strncpy(key, "9440", 4);
 					break;
+
+				case 0x09:
+					/* for PX-G900 -- New Ink i	2004.01.20	*/
+					/* Red		*/
+					strncpy(key, "9020", 4);
+					break;
+				case 0x0A:
+					/* for PX-G900 -- New Ink i	2004.01.20	*/
+					/* Viloet	*/
+					strncpy(key, "A040", 4);
+					break;
+				case 0x0B:
+					/* for PX-G900 -- New Ink i	2004.01.20	*/
+					/* Clear	*/
+					strncpy(key, "B080", 4);
+					break;
+					
 				default:
 					/* fprintf(stderr, "Unknown Ink (0x%02x)\n", point[i * 3 + 1]); */
 					return 0;
