@@ -57,7 +57,6 @@ enum ALIGNMENT_TYPE
 	TYPE_RULED_COLOR,
 	TYPE_PATCH_COLOR,
 	TYPE_BAND_COLOR,
-
 	TYPE_PATCH_EXT,			/* Added for PM-G700 */
 	TYPE_PATCH_EXT_COLOR,
 
@@ -373,7 +372,8 @@ init_alignment (char* printer, int ruled, int patch, int band,
 	      || !strcmp (model, "PX-V700") 
 	      || !strcmp (model, "CC-600PX")
 	      || !strcmp (model, "Stylus CX5100_5200 Series") 
-	      || !strcmp (model, "Stylus CX5300_5400 Series"))
+	      || !strcmp (model, "Stylus CX5300_5400 Series")
+	      || !strcmp (model, "Stylus CX6300_6400 Series"))
 	{
 		_navi_info.align_val[TYPE_RULED] = 5;
 		_navi_info.align_val[TYPE_RULED_COLOR] = 4;
@@ -445,25 +445,28 @@ init_alignment (char* printer, int ruled, int patch, int band,
 
 		_navi_info.sn_flag = 1 ;
 	}
-	else if (!strcmp (model, "PM-G700") || !strcmp (model, "PM-A850") || !strcmp (model, "PM-D750") 
-			|| !strcmp (model, "Stylus Photo R300_310") || !strcmp (model, "Stylus Photo R200_210"))
+	else if (!strcmp (model, "PM-G700") || !strcmp (model, "PM-A850") || !strcmp (model, "PM-D750")
+			|| !strcmp (model, "Stylus Photo R300_310") || !strcmp (model, "Stylus Photo R200_210")
+			|| !strcmp (model, "Stylus Photo RX600_610") || !strcmp (model, "Stylus Photo RX500_510"))
 	{
 		_navi_info.align_val[TYPE_PATCH_EXT]       = 4;
 		_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 4;
 		if( !strcmp (model, "PM-G700") || !strcmp (model, "PM-D750") || !strcmp (model, "Stylus Photo R300_310")
-			|| !strcmp (model, "Stylus Photo R200_210"))
+			|| !strcmp (model, "Stylus Photo R200_210") || !strcmp (model, "Stylus Photo RX500_510"))
 			_navi_info.ex_bits = NAVI_EX_PMG700;
-		if( !strcmp (model, "PM-A850") )
+		if( !strcmp (model, "PM-A850") || !strcmp (model, "Stylus Photo RX600_610") )
 			_navi_info.ex_bits = NAVI_EX_PMA850;
 
-	}else if (!strcmp (model, "Stylus C64_63 Series" )){
+	}else if (!strcmp (model, "Stylus C64_63 Series" ) || !strcmp (model, "PX-V500" ) 
+			|| !strcmp (model, "Stylus C65_66 Series" )){
 		_navi_info.align_val[TYPE_PATCH_EXT]       = 4;
 		_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 4;
 		_navi_info.align_val[TYPE_BAND]       = 1;
 		_navi_info.align_val[TYPE_BAND_COLOR] = 1;
 		_navi_info.ex_bits = NAVI_EX_SC64_63S;
 
-	}else if (!strcmp (model, "PX-V600" ) || !strcmp (model, "Stylus C84_83 Series" )){
+	}else if (!strcmp (model, "PX-V600" ) || !strcmp (model, "Stylus C84_83 Series" )
+	       || !strcmp (model, "Stylus C85_86 Series" )){
 		_navi_info.align_val[TYPE_PATCH_EXT]       = 5;
 		_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 4;
 		_navi_info.align_val[TYPE_BAND]       = 1;
@@ -471,7 +474,8 @@ init_alignment (char* printer, int ruled, int patch, int band,
 		_navi_info.ex_bits = NAVI_EX_PXV600;
 
 	}
-	else if (!strcmp (model, "PM-G800"))
+	else if (!strcmp (model, "PM-G800") || !strcmp (model, "PX-G900") 
+			|| !strcmp (model, "Stylus Photo R800"))
 	{
 		_navi_info.align_val[TYPE_PATCH_EXT]       = 3;
 		_navi_info.ex_bits = NAVI_EX_PMG800;
@@ -1674,11 +1678,20 @@ align_patch_ext_navi (int page)
 
 		len = strlen (_navi_info.align_path[TYPE_PATCH_EXT]) - strlen ("COLOR");
 		if (strncmp (_navi_info.align_path[TYPE_PATCH_EXT] + len, "COLOR", strlen ("COLOR"))){
-			display_message (GTK_TEXT(text),
+			if(_navi_info.ex_bits == NAVI_EX_PMG800 ){
+				display_message (GTK_TEXT(text),
+				_("A vertical alignment sheet will be printed.\n\n"
+				  "Make sure that the printer is turned on and connected to the computer.\n"
+				  "Also make sure that A4 size plain paper is loaded in the sheet feeder.\n\n"
+				  "Click \"Next\" when ready."));
+			}else{
+				display_message (GTK_TEXT(text),
 				_("A black vertical alignment sheet will be printed.\n\n"
 				  "Make sure that the printer is turned on and connected to the computer.\n"
 				  "Also make sure that A4 size plain paper is loaded in the sheet feeder.\n\n"
 				  "Click \"Next\" when ready."));
+			}
+
 		}else{
 			display_message (GTK_TEXT(text),
 				_("A color vertical alignment sheet will be printed.\n\n"
@@ -1811,7 +1824,7 @@ align_patch_ext_navi (int page)
 					}else{
 						if(_navi_info.ex_bits == NAVI_EX_PXV600 ){
 							/* model depndent color pattern 4/mono patern 5 */
-							/* skip first index and ... 			*/ 
+							/* skip first index and ... 			*/
 							alignment_set_dd[5] = (i+2)%(modulo+1);
 						}else{
 							alignment_set_dd[5] = (i+1)%modulo;
