@@ -19,6 +19,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
@@ -105,6 +108,22 @@ typedef struct{
 
 static PRINTSTSSTRUCT _status_str;
 
+/* 2004.03.08		*/	
+/* ink color name 	*/
+static const char *ink_name[] = {
+  N_("NBlack"),
+  N_("Cyan"),
+  N_("Magenta"),
+  N_("Yellow"),
+  N_("Light Cyan"),
+  N_("Light Magenta"),
+  N_("Dark Yellow"),
+  N_("Photo Black"),
+  N_("Matte Black"),
+  N_("Red"),
+  N_("Blue"),
+  N_("Gloss Optimizer")
+};
 
 static PRINTER_STS ReadStatuslogfile (InkList *);
 static void SetAllUserButtonHidden (void);
@@ -150,8 +169,7 @@ ReadStatuslogfile (InkList *list)
 
 	/* 󥯼 */
 	lpInk = strstr (lpReply, "INK:");
-	if (lpInk)
-	{
+	if (lpInk){
 		char ic[7] = "0x";
 		InkNode *prev = NULL;
 
@@ -181,6 +199,65 @@ ReadStatuslogfile (InkList *list)
 			}
 			node = node->next;
 		}
+	}else{
+		char snink[3];
+		int  nink, i;
+		InkNode *prev = NULL;
+
+		/* 2004.03.18		*/
+		/* INK:... not reply 	*/
+		/* check "AI:CW:"	*/
+		lpInk = strstr (lpReply, "AI:CW:");
+		if( !lpInk )	
+			return STS_NO_REPLY;
+		/* Found!		*/	
+		lpInk += 6;	/* skip "AI:CW:" */
+
+		/* get no. of ink */
+		sprintf( snink, "%.2s", lpInk);
+		nink = atoi( snink );		
+		lpInk += 2;
+
+		/* setup ink list */
+		for( i = 0; i < nink ; i++ ){
+			InkNode *node;
+
+			node = (InkNode *)calloc(1, sizeof(InkNode));
+			if (!node) {
+				return STS_NO_REPLY;
+			}
+
+			switch( i ){
+			case	0: /* black */
+				node->id = 0x1101;break;	
+			case	1: /* cyan */
+				node->id = 0x3202;break;
+			case	2: /* yellow */
+				node->id = 0x4304;break;
+			case	3: /* magenta */
+				node->id = 0x5408;break;
+			case	4: /* light cyan */
+				node->id = 0x6210;break;
+			case	5: /* light magenta */
+				node->id = 0x7320;break;
+			case	6: /* dark yellow */
+				node->id = 0x9440;break;
+			case	7: /* light black */
+				node->id = 0x1140;break;
+			default	:
+				node->id = 0x0;break;
+			   break;
+			}
+			
+			if (prev) {
+				prev->next = node;
+				prev = prev->next;
+			} else {
+				prev = node;
+				*list = prev;
+			}
+			node = node->next;
+		}
 	}
 
 
@@ -619,8 +696,10 @@ GetPrinterStatus (gpointer data)
 						    "To cancel print jobs, click the Cancel button."));
 		SetAllUserButtonHidden();
 
-		widget = lookup_widget (_status_str.window, "close_button");
+		/* 2004.03.02 close button -> cancel button */
+		widget = lookup_widget (_status_str.window, "cancel_button");
 		gtk_widget_show(widget);
+		
 		break;
 
 	case STS_ERR_THICK_PAPER:
@@ -1004,6 +1083,10 @@ setInkProg(InkList list)
 	int i;
 	char pix_name[] = "pixmap?";
 
+	/* 2004.03.08 for tooltips */
+	GtkTooltipsData *tips;
+	GtkWidget *event;
+	char event_name[] = "eventbox?";
 
 	while (node) {
 		if (node->rest < 0 || node->rest > 100) {
@@ -1029,7 +1112,8 @@ setInkProg(InkList list)
 		
 		pix_name[6] = '1' + _status_str.inkbox_counter;
 		pix = lookup_widget (_status_str.window, pix_name);
-		
+
+
 		inkbox_chenge_volume (_status_str.inkbox_xpm, node->id, node->rest);
 		inkbox_pixmap = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
 							     &inkbox_mask, NULL,
@@ -1041,6 +1125,11 @@ setInkProg(InkList list)
 		gdk_pixmap_unref (inkbox_pixmap);
 		gdk_bitmap_unref (inkbox_mask);
 		
+		/* 2004.03.08 for tooltips */
+		event_name[8] = '1' + _status_str.inkbox_counter;
+		event = lookup_widget (_status_str.window, event_name);
+		gtk_widget_show ( event );
+		
 		_status_str.inkbox_use_flag[_status_str.inkbox_counter] = 1;
 		_status_str.inkbox_counter++;
 	}
@@ -1050,9 +1139,14 @@ setInkProg(InkList list)
 		{
 			pix_name[6] = '1' + i;
 			pix = lookup_widget (_status_str.window, pix_name);
+
+			/* 2004.03.08 for tooltips */
+			event_name[8] = '1' + i;
+			event = lookup_widget (_status_str.window, event_name);
 			
 			if (node != NULL && (node->rest >= 0 && node->rest <= 100))
 			{
+
 				inkbox_chenge_volume (_status_str.inkbox_xpm, node->id, node->rest);
 				inkbox_pixmap = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
 									     &inkbox_mask, NULL,
@@ -1064,11 +1158,22 @@ setInkProg(InkList list)
 				gtk_widget_show (pix);
 				gdk_pixmap_unref (inkbox_pixmap);
 				gdk_bitmap_unref (inkbox_mask);
+
+				/* 2004.03.08		    */
+				/* set tooltips label again */
+				tips = gtk_tooltips_data_get( event );
+				if( tips ){
+					gtk_tooltips_set_tip( tips->tooltips, tips->widget,
+						       (char*)_(ink_name[ inkbox_get_inkid(node->id) ]), NULL );	
+				}
+				gtk_widget_show ( event );
+				
 				node = node->next;
 			}
 			else
 			{
 				_status_str.inkbox_use_flag[i] = 0;
+				gtk_widget_hide ( event );
 				gtk_widget_hide (pix);
 			}
 		}
