@@ -57,9 +57,9 @@ const char *outputLabels[] = {
   N_("to file"),
   NULL,
 };
-  
+
 const char *outputTypeLabels = N_("export file");
-  
+
 const char *finishButtonLabels[] = {
   N_("Save"),
   N_("Print"),
@@ -68,13 +68,13 @@ const char *finishButtonLabels[] = {
 };
 
 const char *def_margin_label = N_("Default");
-  
+
 OPTION_DATA inkData[] = {
   {     PIPS_OUTPUT_CMYKcm,     "COLOR",        N_("Color")        },
   {     PIPS_OUTPUT_MONO,       "MONO",         N_("Black")        },
   {     END_ARRAY,              "",             ""             }
 };
-  
+
 OPTION_DATA mediaSizeData[] = {
     { PIPS_PAPER_A4,            "A4",       N_("A4  210x297 mm")                    },
     { PIPS_PAPER_A5,            "A5",       N_("A5  148x210 mm")                    },
@@ -92,18 +92,26 @@ OPTION_DATA mediaSizeData[] = {
     { PIPS_PAPER_JENV_YOU3,     "ENVY3",    N_("Envelope  98x148 mm")               },
     { PIPS_PAPER_JENV_YOU4,     "ENVY4",    N_("Envelope  105x235 mm")              },
     { PIPS_PAPER_TRIM_4X6,      "4X6",      N_("4x6 100x152 mm")                    },
-#if SPR300_310 || SPR200_210
+#if SPR300_310 || SPR200_210 || SPRX600_610 || SPRX500_510 || SPR800
     { PIPS_PAPER_TRIM_L,        "L",        N_("3.5x5 in (9x13 cm)")                },
 #else
     { PIPS_PAPER_TRIM_L,        "L",        N_("3.5x5 in  89x127 mm")               },
 #endif
+#if SPR800
+    { PIPS_PAPER_TRIM_NAMECARD, "NC",       N_("Business Card 89x50 mm")            },
+#else
     { PIPS_PAPER_TRIM_NAMECARD, "NC",       N_("Business Card 89x55 mm")            },
-#if SPR300_310 || SPR200_210
+#endif
+#if SPR300_310 || SPR200_210 || SPRX600_610 || SPRX500_510 || SPR800
     { PIPS_PAPER_TRIM_2L,        "2L",      N_("5x7 in (13x18 cm)")                  },
 #else
     { PIPS_PAPER_TRIM_2L,        "2L",      N_("5x7 in  127x178 mm")                },
 #endif
+#if SPR800
+	{ PIPS_PAPER_TRIM_LL,        "LL",      N_("3.5x5 in(Landscape)  13x9 cm")      },
+#else
     { PIPS_PAPER_TRIM_LL,        "LL",      N_("3.5x5 in(Landscape)  127x89 mm")    },
+#endif
     { PIPS_PAPER_A3,            "A3",       N_("A3  297x420 mm")                    },
     { PIPS_PAPER_A3_PLUS,       "A3+",      N_("Super A3 / B  329x483 mm")          },
     { PIPS_PAPER_B4,            "B4",       N_("B4  257x364 mm")                    },
@@ -115,7 +123,8 @@ OPTION_DATA mediaSizeData[] = {
     { PIPS_PAPER_ENV_DL,        "ENVDL",    N_("Envelope DL  110x220 mm")           },
     { PIPS_PAPER_ENV_C6,        "ENVC6",    N_("Envelope C6  114x162 mm")           },
     { PIPS_PAPER_ENV_FOR5X8,    "ENV5X8",   N_("Envelope 132x220 mm")               },
-#if SPR300_310 || SPR200_210
+#if SPR300_310 || SPR200_210 || SPRX600_610 || SPRX500_510 || SCX6300_6400S || SPR800 \
+ || SC65_66S   || SC85_86S
     { PIPS_PAPER_PHOTO_100x150, "PP100",    N_("10x15 cm Photo")                    },
     { PIPS_PAPER_PHOTO_200x300, "PP200",    N_("20x30 cm Photo")                    },
 #else
@@ -124,7 +133,7 @@ OPTION_DATA mediaSizeData[] = {
 #endif
     { PIPS_PAPER_4X6FULL,       "4X6FULL",  N_("Photo Paper 4x6 in  No Perforations")},
     { PIPS_PAPER_PANORAMIC,     "PANORAM",  N_("Panoramic 210x594 mm")              },
-    
+
     { PIPS_PAPER_BUSINESS_CARD,  "NC91",  N_("Business Card 55x91 mm")              },
     { PIPS_PAPER_CREDITCARD,     "CARD",  N_("Card 54x86 mm")                       },
     /* 2003/11/11 Added */
@@ -198,14 +207,23 @@ OPTION_DATA mediaTypeData[] = {
   {     PIPS_MED_EOHP,         "EOHP",  N_("EPSON Ink Jet Transparencies")},
 /*   {     PIPS_MED_P_ALBUM,      "P_ALBUM",N_("Photo Album Paper")}, */
   {     PIPS_MED_P_BOARD,      "P_BOARD",N_("Photo Board Paper")},
+ 
+  /* 2004.01.07 Added */
+  {     PIPS_MED_ADDRESSSIDE,  "ADDRESS",N_("Post Card Address Side")},
+  {     PIPS_MED_SF_POSTCARD,  "SFPC",   N_("Super Fine Post Card")},
 
 #if	(PM940C) || (PM980C)
-  // silent mask -> 
+  // silent mask 
   {     PIPS_MED_PLAIN|SILENT_MASK, "PLAIN_SILENT",    N_("Plain Paper (Silent Feed)")   },
   {     PIPS_MED_EPP|SILENT_MASK,   "EPP_SILENT",      N_("EPSON Glossy Paper (Silent Feed)") },
 #endif
   // new media type for only one mode.
   {     PIPS_MED_PLAIN_SPEED, "PLAIN_SPEED",    N_("Plain Paper (Fast)")   },
+
+  // 2004.03.31
+  // new media type for "Black Ink Save"
+  {     PIPS_MED_PLAIN_BKSAVE, "PLAIN_BKSAVE",    N_("Plain Paper (Black Ink Save Mode)")   },
+
   {     END_ARRAY,             "",         ""                       }
 
 };
@@ -261,19 +279,19 @@ OPTION_DATA levelData[] = {
   {     PIPS_LV_PHOTO,          "PHOTO",        N_("Photo")           },
   {     PIPS_LV_SPHOTO,         "SPHOTO",       N_("Super Photo")     },
 #elif (HIGH_RESOLUTION == 1) 
-  /*  */
+  /* High Resolution Pattern 1 */
   {     PIPS_LV_DRAFT,          "DRAFT",        N_("Draft")           },
-  {     PIPS_LV_STD360,         "STD360",       N_("STD  (360dpi)")        },
-  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")        },
+  {     PIPS_LV_STD360,         "STD360",       N_("Standard (360dpi)")   },
+  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")       },
   {     PIPS_LV_SFINE720,       "SFINE720",     N_("Super Fine (720dpi)") },
   {     PIPS_LV_PHOTO1440,      "PHOTO1440",    N_("Photo (1440dpi)")     },
   {     PIPS_LV_PHOTO2880,      "PHOTO2880",    N_("Photo (2880dpi)")     },
   {     PIPS_LV_SPHOTO2880,     "SPHOTO2880",   N_("Super Photo (2880dpi)") },
 #else
-  /* 2 */
+  /* High Resolution Pattern 2 */
   {     PIPS_LV_DRAFT,          "DRAFT",        N_("Draft")           },
-  {     PIPS_LV_STD360,         "STD360",       N_("STD  (360dpi)")        },
-  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")        },
+  {     PIPS_LV_STD360,         "STD360",       N_("Standard (360dpi)")  },
+  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")       },
   {     PIPS_LV_SFINE720,       "SFINE720",     N_("Super Fine (720dpi)") },
   {     PIPS_LV_PHOTO1440,      "PHOTO1440",    N_("Photo (1440dpi)")     },
   {     PIPS_LV_PHOTO2880,      "PHOTO2880",    N_("Photo (2880dpi)")     },
@@ -307,6 +325,8 @@ OPTION_DATA inksetData[] = {
   {     PIPS_INKSET_CMYKcmLk,   "CMYKcmLk",       ""        },
   {     PIPS_INKSET_CMYcmMkLk,  "CMYcmMkLk",      ""        },
   {     PIPS_INKSET_CMYcmMk,    "CMYcmMk",        ""        },
+  {     PIPS_INKSET_CMYKRVCl,   "CMYKRVCl",       ""        },	/* 2004.01.22 New Inkset */
+  {     PIPS_INKSET_CMYKRV,     "CMYKRV",         ""        },	/* 2004.01.22 New Inkset */
   {     END_ARRAY,              "",        ""            }
 };
 
@@ -317,6 +337,16 @@ OPTION_DATA autoCutData[] = {
   {     END_ARRAY,      "",     ""                  }
 };
 
+/* ץƥޥбȼäɲ */
+/* 2004.01.07 Added */
+OPTION_DATA clearInkData[] = {
+  {     PIPS_CI_ON,          "ON",        N_("ON")      },
+  {     PIPS_CI_OFF,         "OFF",       N_("OFF")     },
+  {     PIPS_CI_AUTO,        "AUTO",      N_("ON(AUTO)")     },
+  {     PIPS_CI_FULL,        "FULL",      N_("ON(FULL)")     },
+  {     END_ARRAY,      "",     ""                  }
+};
+
 OPTION_ALL opt_all[] = {
   {     P_SCALE,                NULL,           N_("Reduce/Enlarge (%)")    },
   {     P_INK,                  inkData,        N_("Ink")                   },
@@ -337,6 +367,7 @@ OPTION_ALL opt_all[] = {
   {     P_MULTI_PAGE,           multiPageData,  N_("Multi Page")            },
   {     P_BIN,                  binData,        N_("Paper Source")          },
   {     P_AUTO_CUT,             autoCutData,    N_("Auto Cut")              },
+  {     P_CLEAR_INK,            clearInkData,   N_("Gloss Optimizer")       },
   {     P_STRENGTH_CYAN,        NULL,           N_("Cyan")                  },
   {     P_STRENGTH_MAGENTA,     NULL,           N_("Magenta")               },
   {     P_STRENGTH_YELLOW,      NULL,           N_("Yellow")                },
