@@ -859,9 +859,22 @@ load_image_out (LP_IMG_STRUCT lp_image, LP_MKC_STRUCT lp_mkcode)
 		}
 		
 		/*  */
+#if PXG900 || SPR800
+		{
+			long real_size;
+			long size;
+		
+			real_size = (lp_image->image_size.x * lp_image->magnify.x)
+				- lp_image->negative_margin.x;
+			size = (lp_image->print_size.x > real_size ) ? real_size : lp_image->print_size.x ;
+		
+			set_raster (raster, image, size, lp_image->negative_margin.x,
+			    lp_image->magnify.x, lp_image->byte_p_pixel);
+		}
+#else
 		set_raster (raster, image, lp_image->print_size.x, lp_image->negative_margin.x,
 			    lp_image->magnify.x, lp_image->byte_p_pixel);
-		
+#endif		
 		if (atflag)
 		{
 			atbmp = atbmp_read_attribute ();
@@ -1053,6 +1066,12 @@ conf_print_image (LP_PRT_STRUCT lp_prtinfo, LP_IMG_STRUCT lp_image)
 	}
 
 	/* ΰ */
+#if PXG900 || SPR800
+	/* 2004.02.23 		*/
+	/* for PX-G900		*/
+	/* ѻ極	*/
+	lp_image->print_size.x = lp_prtinfo->paper_area.x - positive_margin_x;
+#else
 	if((lp_prtinfo->paper_area.x - positive_margin_x)
 	   < ((lp_image->image_size.x - lp_image->negative_margin.x) * lp_image->magnify.x))
 	{
@@ -1063,6 +1082,9 @@ conf_print_image (LP_PRT_STRUCT lp_prtinfo, LP_IMG_STRUCT lp_image)
 		lp_image->print_size.x = (lp_image->image_size.x * lp_image->magnify.x)
 			- lp_image->negative_margin.x;
 	}
+#endif
+
+	
 	if (lp_image->print_size.x % 2)
 		lp_image->print_size.x--;
   
@@ -1107,6 +1129,9 @@ set_init_param (LP_LIBPRT_INIT lp_prt_init, LP_PRT_STRUCT lp_prtinfo,
 	lp_prt_init->margin.y     = lp_prtinfo->margin.y;
 	lp_prt_init->inkset       = lp_prtinfo->inkset;
 	lp_prt_init->auto_cut     = lp_prtinfo->auto_cut;
+#if CLEAR_INK
+	lp_prt_init->clear_ink	  = lp_prtinfo->clear_ink;
+#endif
   
 	return;
 }
@@ -1135,9 +1160,20 @@ set_band_param (LP_LIBPRT_BAND lp_prt_band, LP_IMG_STRUCT lp_image)
 	long width_bytes;
 	long width_atbmp_bytes;
 
-	width_pixel = lp_image->print_size.x;
+#if PXG900 || SPR800
+	long real_size;
+	/* 2004.02.20 for PX-G900 */
+	real_size = (lp_image->image_size.x * lp_image->magnify.x)
+			- lp_image->negative_margin.x;
+	width_pixel = (real_size > lp_image->print_size.x) ?lp_image->print_size.x : real_size; 
+	/* byte size is 'print_area_size' */
+	width_bytes = WIDTHBYTES(lp_image->print_size.x * lp_image->byte_p_pixel * 8);
+	width_atbmp_bytes = WIDTHBYTES(lp_image->print_size.x * 8);
+#else
+	width_pixel = lp_image->print_size.x; 
 	width_bytes = WIDTHBYTES(width_pixel * lp_image->byte_p_pixel * 8);
 	width_atbmp_bytes = WIDTHBYTES(width_pixel * 8);
+#endif
 
 	ex_raster = (UCHAR*)pf_mem_alloc (width_bytes * 2);
 	if (!ex_raster)
